Getting started
===============

.. contents::
   :local:


Example inventory
-----------------

``debops.console`` is included by default in the :file:`common.yml` DebOps
playbook; you don't need to do anything to have it executed.


Example playbook
----------------

If you are using this role without DebOps, here's an example Ansible playbook
that uses the ``debops.console`` role:

.. literalinclude:: playbooks/console.yml
   :language: yaml
